@@ -6,6 +6,7 @@ from .commit import commit
 from ...utils.env_keys import REPORT_ERROR_KEY
 from ...utils.http_client import LaunchableClient
 from ...utils.session import clean_session_files
+from ...utils.click import KeyValueType
 from tabulate import tabulate
 from ...utils.authentication import get_org_workspace
 
@@ -49,9 +50,18 @@ from ...utils.authentication import get_org_workspace
     """,
     default=False
 )
+@click.option('--scrub-pii', is_flag=True, help='Scrub emails and names', hidden=True)
+@click.option(
+    '--commit',
+    'commits',
+    help="set repository name and commit hash when you use --no-commit-collection option",
+    multiple=True,
+    default=[],
+    cls=KeyValueType,
+)
 @click.pass_context
 def build(ctx, build_name, source, max_days, no_submodules,
-          no_commit_collection):
+          no_commit_collection, scrub_pii, commits):
     if "/" in build_name:
         exit("--name must not contain a slash")
 
@@ -68,7 +78,8 @@ def build(ctx, build_name, source, max_days, no_submodules,
             fg='yellow'), err=True)
     else:
         for (name, repo_dist) in repos:
-            ctx.invoke(commit, source=repo_dist, max_days=max_days)
+            ctx.invoke(commit, source=repo_dist,
+                       max_days=max_days, scrub_pii=scrub_pii)
 
     sources = [(
         name,
@@ -99,6 +110,18 @@ def build(ctx, build_name, source, max_days, no_submodules,
                         submodules.append(
                             (repo_name + "/" + name, repo_dist + "/" + name, commit_hash))
 
+    if no_commit_collection and len(commits) != 0:
+        invalid = False
+        for repo_name, hash in commits:
+            if not re.match("[0-9A-Fa-f]{5,40}$", hash):
+                click.echo(click.style(
+                    "{}'s commit hash `{}` is invalid.".format(repo_name, hash), fg="yellow"
+                ), err=True)
+                invalid = True
+            submodules.append((repo_name, "", hash))
+        if invalid:
+            exit(1)
+
     # Note: currently becomes unique command args and submodules by the hash.
     # But they can be conflict between repositories.
     uniq_submodules = {commit_hash: (name, repo_dist, commit_hash)
