@@ -27,7 +27,8 @@ jar_file_path = os.path.normpath(os.path.join(
               help="the maximum number of days to collect commits retroactively",
               default=30
               )
-def commit(source, executable, max_days):
+@click.option('--scrub-pii', is_flag=True, help='[Deprecated] Scrub emails and names', hidden=True)
+def commit(source, executable, max_days, scrub_pii):
     source = os.path.abspath(source)
 
     if executable == 'jar':
@@ -54,10 +55,11 @@ def exec_jar(source, max_days):
     proxy_option = _build_proxy_option(https_proxy) if https_proxy else ""
 
     os.system(
-        "{} {} -jar \"{}\" ingest:commit -endpoint {} -max-days {} {} {}"
+        "{} {} -jar \"{}\" ingest:commit -endpoint {} -max-days {} {} {} {}"
         .format(java, proxy_option, jar_file_path,
                 "{}/intake/".format(base_url), max_days,
                 "-audit" if Logger().logger.isEnabledFor(LOG_LEVEL_AUDIT) else "",
+                "-scrub-pii",
                 source))
 
 
